package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.ApiInterfaceMapper;
import com.zyc.system.domain.ApiInterface;
import com.zyc.system.service.IApiInterfaceService;

/**
 * API接口清单Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class ApiInterfaceServiceImpl implements IApiInterfaceService 
{
    @Autowired
    private ApiInterfaceMapper apiInterfaceMapper;

    /**
     * 查询API接口清单
     * 
     * @param id API接口清单主键
     * @return API接口清单
     */
    @Override
    public ApiInterface selectApiInterfaceById(Integer id)
    {
        return apiInterfaceMapper.selectApiInterfaceById(id);
    }

    /**
     * 查询API接口清单列表
     * 
     * @param apiInterface API接口清单
     * @return API接口清单
     */
    @Override
    public List<ApiInterface> selectApiInterfaceList(ApiInterface apiInterface)
    {
        return apiInterfaceMapper.selectApiInterfaceList(apiInterface);
    }

    /**
     * 新增API接口清单
     * 
     * @param apiInterface API接口清单
     * @return 结果
     */
    @Override
    public int insertApiInterface(ApiInterface apiInterface)
    {
        return apiInterfaceMapper.insertApiInterface(apiInterface);
    }

    /**
     * 修改API接口清单
     * 
     * @param apiInterface API接口清单
     * @return 结果
     */
    @Override
    public int updateApiInterface(ApiInterface apiInterface)
    {
        return apiInterfaceMapper.updateApiInterface(apiInterface);
    }

    /**
     * 批量删除API接口清单
     * 
     * @param ids 需要删除的API接口清单主键
     * @return 结果
     */
    @Override
    public int deleteApiInterfaceByIds(Integer[] ids)
    {
        return apiInterfaceMapper.deleteApiInterfaceByIds(ids);
    }

    /**
     * 删除API接口清单信息
     * 
     * @param id API接口清单主键
     * @return 结果
     */
    @Override
    public int deleteApiInterfaceById(Integer id)
    {
        return apiInterfaceMapper.deleteApiInterfaceById(id);
    }
}
